@@ -11,9 +11,9 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+/* Disable this and use a threaded perl to test MSVC compilation errors */
 #define PERL_NO_GET_CONTEXT     /* we want efficiency */
 
-
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
@@ -629,10 +629,10 @@ PmmGenNsName( const xmlChar * name, const xmlChar * nsURI )
     }
     namelen = xmlStrlen( name );
 
-    retval =xmlStrncat( retval, (const xmlChar *)"{", 1 );
+    retval = xmlStrncat( retval, (const xmlChar *)"{", 1 );
     if ( nsURI != NULL ) {
         urilen = xmlStrlen( nsURI );
-        retval =xmlStrncat( retval, nsURI, urilen );
+        retval = xmlStrncat( retval, nsURI, urilen );
     }
     retval = xmlStrncat( retval, (const xmlChar *)"}", 1 );
     retval = xmlStrncat( retval, name, namelen );
@@ -845,22 +845,23 @@ PmmGenLocator( xmlSAXLocatorPtr loc)
 void
 PmmUpdateLocator( xmlParserCtxtPtr ctxt )
 {
+    dTHX;
+    const xmlChar * encoding;
+    const xmlChar * version;
     PmmSAXVectorPtr sax = (PmmSAXVectorPtr)ctxt->_private;
 
     if (sax->locator == NULL) {
         return;
     }
 
-    dTHX;
-
     (void) hv_store(sax->locator, "LineNumber", 10,
          newSViv(ctxt->input->line), 0);
 
     (void) hv_store(sax->locator, "ColumnNumber", 12,
          newSViv(ctxt->input->col), 0);
 
-    const xmlChar * encoding = ctxt->input->encoding;
-    const xmlChar * version = ctxt->input->version;
+    encoding = ctxt->input->encoding;
+    version = ctxt->input->version;
 
     if ( encoding != NULL && XML_STR_NOT_EMPTY( encoding ) ) {
       (void) hv_store(sax->locator, "Encoding", 8,
@@ -929,9 +930,8 @@ PSaxStartDocument(void * ctx)
     SV * rv;
     if ( handler != NULL ) {
 
-        PmmUpdateLocator(ctx);
-
         dSP;
+        PmmUpdateLocator(ctx);
 
         ENTER;
         SAVETMPS;
@@ -1211,11 +1211,10 @@ PSaxComment(void *ctx, const xmlChar * ch) {
     dTHX;
     HV* element;
     SV * handler = sax->handler;
+    SV * rv = NULL;
 
     PmmUpdateLocator(ctx);
 
-    SV * rv = NULL;
-
     if ( ch != NULL && handler != NULL ) {
         dSP;
 
@@ -1256,14 +1255,12 @@ PSaxCDATABlock(void *ctx, const xmlChar * ch, int len) {
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr)ctx;
     PmmSAXVectorPtr sax = (PmmSAXVectorPtr)ctxt->_private;
     dTHX;
-
-    PmmUpdateLocator(ctx);
-
     HV* element;
     SV * handler = sax->handler;
-
     SV * rv = NULL;
 
+    PmmUpdateLocator(ctx);
+
     if ( ch != NULL && handler != NULL ) {
         dSP;
 
@@ -1328,12 +1325,11 @@ PSaxProcessingInstruction( void * ctx, const xmlChar * target, const xmlChar * d
     PmmSAXVectorPtr sax   = (PmmSAXVectorPtr)ctxt->_private;
     dTHX;
     SV * handler          = sax->handler;
-
-    PmmUpdateLocator(ctx);
-
     SV * element;
     SV * rv = NULL;
 
+    PmmUpdateLocator(ctx);
+
     if ( handler != NULL ) {
         dSP;
 
@@ -1375,14 +1371,14 @@ void PSaxExternalSubset (void * ctx,
 {
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr)ctx;
     PmmSAXVectorPtr sax   = (PmmSAXVectorPtr)ctxt->_private;
-    PmmUpdateLocator(ctx);
 
     dTHX;
     SV * handler          = sax->handler;
-
     SV * element;
     SV * rv = NULL;
 
+    PmmUpdateLocator(ctx);
+
     if ( handler != NULL ) {
         dSP;
 
